dlk package
===========

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   dlk.core
   dlk.data
   dlk.managers
   dlk.utils

Submodules
----------

dlk.online module
-----------------

.. automodule:: dlk.online
   :members:
   :undoc-members:
   :show-inheritance:

dlk.predict module
------------------

.. automodule:: dlk.predict
   :members:
   :undoc-members:
   :show-inheritance:

dlk.process module
------------------

.. automodule:: dlk.process
   :members:
   :undoc-members:
   :show-inheritance:

dlk.train module
----------------

.. automodule:: dlk.train
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: dlk
   :members:
   :undoc-members:
   :show-inheritance:
